@@ -16,6 +16,7 @@ ObjectClass = Literal["person", "vehicle", "animal", "motion", "other"]
 CameraRole = Literal["high-resolution", "mid-resolution", "low-resolution", "snapshot"]
 StreamingRole = Literal["high-resolution", "mid-resolution", "low-resolution"]
 VideoStreamingMode = Literal["auto", "webrtc", "mse", "webrtc/tcp"]
+CameraAspectRatio = Literal["16:9", "8:3", "4:3", "auto"]
 DecoderFormat = Literal["yuv420p", "rgb24", "nv12"]
 ImageInputFormat = Literal["yuv420p", "nv12", "rgb", "rgba", "gray"]
 ImageOutputFormat = Literal["rgb", "rgba", "gray"]
@@ -191,7 +192,7 @@ class VideoStreamInfo(TypedDict):
 
 class ProbeConfig(TypedDict, total=False):
     video: bool
-    audio: Union[Literal["all"], list[ProbeAudioCodec]]
+    audio: Union[bool, Literal["all"], list[ProbeAudioCodec]]
     microphone: bool
 
 
@@ -595,6 +596,7 @@ class ReturnAudioFFmpegOptions(TypedDict):
 class CameraUiSettings(TypedDict):
     streamingMode: VideoStreamingMode
     streamingSource: Union[StreamingRole, Literal["auto"]]
+    aspectRatio: CameraAspectRatio
 
 
 class CameraRecordingSettings(TypedDict):
